@@ -22,20 +22,21 @@
 #include "k3bview.h"
 #include "k3bdoc.h"
 
-#include <KAction>
-#include <KActionMenu>
-#include <KDebug>
-#include <KIconLoader>
-#include <KLocale>
-#include <KMenu>
-#include <KUrl>
+#include <KI18n/KLocalizedString>
+#include <KIconThemes/KIconLoader>
+#include <KWidgetsAddons/KActionMenu>
 
-#include <QDragEnterEvent>
-#include <QDragMoveEvent>
-#include <QDropEvent>
-#include <QMimeData>
-#include <QMouseEvent>
-#include <QTabBar>
+#include <QtCore/QDebug>
+#include <QtCore/QMimeData>
+#include <QtCore/QUrl>
+#include <QtGui/QDragMoveEvent>
+#include <QtGui/QIcon>
+#include <QtGui/QDropEvent>
+#include <QtGui/QDragEnterEvent>
+#include <QtGui/QMouseEvent>
+#include <QtWidgets/QAction>
+#include <QtWidgets/QMenu>
+#include <QtWidgets/QTabBar>
 
 namespace {
     
@@ -133,7 +134,7 @@ K3b::Doc* K3b::ProjectTabWidget::currentTab() const
 }
 
 
-void K3b::ProjectTabWidget::addAction( KAction* action )
+void K3b::ProjectTabWidget::addAction( QAction* action )
 {
     d->projectActionMenu->addAction( action );
 }
@@ -186,7 +187,7 @@ bool K3b::ProjectTabWidget::eventFilter( QObject* o, QEvent* e )
             QDropEvent* de = static_cast<QDropEvent*>(e);
             if( de->mimeData()->hasUrls() ) {
                 if( Doc* doc = projectAt( de->pos() ) ) {
-                    KUrl::List urls;
+                    QList<QUrl> urls;
                     Q_FOREACH( const QUrl& url, de->mimeData()->urls() ) {
                         urls.append( url );
                     }
@@ -205,7 +206,7 @@ void K3b::ProjectTabWidget::slotDocChanged( K3b::Doc* doc )
 {
     // we need to cache the icon changes since the changed() signal will be emitted very often
     if( !d->projectDataMap[doc].modified ) {
-        setTabIcon( indexOf( doc->view() ), KIcon( "document-save" ) );
+        setTabIcon( indexOf( doc->view() ), QIcon::fromTheme( "document-save" ) );
         d->projectDataMap[doc].modified = true;
 
         // we need this one for the session management
@@ -229,5 +230,5 @@ void K3b::ProjectTabWidget::slotTabCloseRequested( int index )
     }
 }
 
-#include "k3bprojecttabwidget.moc"
+
 
